/label "Documentation"

## Summary

(Briefly describe the documentation change and purpose.)


## Type of documentation change (select all that apply)

- [ ] New page / tutorial
- [ ] Section addition / expansion
- [ ] Correction / typo fix
- [ ] Re-organization / restructuring
- [ ] Formatting / styling (Markdown, LaTeX, images, etc.)
- [ ] Deprecation notice
- [ ] Other (specify): __________


## Affected Files / Sections

(List the files, paths or sections affected by the changes.)


## Description

(If relevant, provide a thorough explanation of what will be changed and why.)
